MyAlertDialog<T> class

Inheritance

Constructors

MyAlertDialog({Key? key, Widget? title, EdgeInsetsGeometry? titlePadding, Widget? content, EdgeInsetsGeometry contentPadding = const EdgeInsets.fromLTRB(24.0, 20.0, 24.0, 24.0), List<Widget>? actions, String? semanticLabel, Widget divider = const Divider(height: 0.0), bool isDividerEnabled = true})
Creates an alert dialog.
const

Properties

actions → List<Widget>?
The (optional) set of actions that are displayed at the bottom of the dialog.
final
content → Widget?
The (optional) content of the dialog is displayed in the center of the dialog in a lighter font.
final
contentPadding → EdgeInsetsGeometry
Padding around the content.
final
divider → Widget
The (optional) horizontal separator used between title, content and actions.
final
hashCode → int
The hash code for this object.
no setterinherited
isDividerEnabled → bool
divider is not displayed if set to false. Default is set to true.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel → String?
The semantic label of the dialog used by accessibility frameworks to announce screen transitions when the dialog is opened and closed.
final
title → Widget?
The (optional) title of the dialog is displayed in a large font at the top of the dialog.
final
titlePadding → EdgeInsetsGeometry?
Padding around the title.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited